#+gcl (IN-PACKAGE "SERROR") 
(IN-PACKAGE "MAXIMA") 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM) *) FRAME-INFO DBM-UP)) 
(PROCLAIM '(FTYPE (FUNCTION * (VALUES T T)) SYMBOLCONC GEN-NAME)) 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM T FIXNUM) T) CPTOM)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) FIXNUM) COMPLM SIGN-GJC HAULONG DECIMALSIN
            $ARRAY_NUMBER_OF_DIMENSIONS LOG2 NESTLEV RATDEGREE INFCOUNT
            PRMUSIGN $POLYSIGN FLATSIZE FLATC OPT-HASH ERROR-SIZE
            SIGNUM)) 
(PROCLAIM
    '(FTYPE (FUNCTION (FIXNUM) T) CMNULL FIXNUM-CFACTOR CHECKFIT
            OUTPUT-LINEAR-ONE-LINE TYOTBSP INDEX* RCPLYGAM CMNULLF
            STYOTBSP)) 
(PROCLAIM '(FTYPE (FUNCTION (T) (VALUES T T)) $MKEY ASCII)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) FIXNUM) RELATIVE-LINE +MSET
            $ARRAY_DIMENSION_N REVAL FORCEBREAK LOGN TMFACTORIAL)) 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T) T) FIRSTN MTYOTBSP RAND)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T FIXNUM) T) TRACEMOD0 P2CPOL J[N]-BESSEL
            I[N]-BESSEL DIAGP CPTIMESXA OUTPUT CHECKBREAK OUTPUT-2D
            OUTPUT-LINEAR EXPANDEXPT SPRDET TDBU NZL CPBQ1 POWRS
            EXPONENTIATE-SUM KTERMS)) 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T) FIXNUM) ARRAY-DIMENSION-N)) 
(PROCLAIM
    '(FTYPE (FUNCTION (FIXNUM FIXNUM) T) UPDATE-HEIGHTS CURSORPOS*
            COMBINATION)) 
(PROCLAIM '(FTYPE (FUNCTION (T (VECTOR T) FIXNUM) T) MAKE-BREAK-POINT)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) *) GCALL3 STORE-INTERNAL-2D
            MARRAYSET-GENSUB LISPM-MFUNCTION-CALL-AUX)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T T T T) *) DIMENSION)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) *) LHOSPITAL-CATCH SASSQ SASSQ1
            MARRAYREF-GENSUB SCAN-DIGITS TRIG-CONST)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T *) *) MASET1
            APPLY-IN$BIND_DURING_TRANSLATION)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) T) MAPPLY SP1PUTBUC1 SP1SINCOS1 SP1ADDTO FMAP1
            GETLABELS DNQF BADFUNCHK DSKRAT-SUBST DGQF DISPFUN1 DLQF
            CONSFUNDEF T//$-FOO COEFFICIENT SIMP-%SEC SIMP-%CSC
            SIMP-%COT $ILT FACT20 NPROD KERNSUBST CDINF CD1 DEGVECTOR
            MARK-0 MEMSIMILARL MEMSIMILAR MARK+0 REVEAL MARK+3
            ESTCHECK2 ATDECODE MARK+1 ZFF LCHK FACRTIMES $PADE PADE
            FACT LET-MACRO-HAIR LHSIMP TCONS3 MARK-1 DBUNIVAR UNI
            SIMPPLOG SQFRNORM RGSUBST PVSUBST SIMPBETA $ALGNORM EXPAND1
            GAMMAC SIMPERF SIMPBINOCOEF NEWDET MULTBK SIMPGAMMA
            COEFMATRIX NISSEARCH NISMATCH NISARGMATCH NISARGSCHECKER
            KILL NISEXPOCHECK PUT-TRACE-INFO SIMP-%SIN SIMP-%COS
            MAKE-TRACE-HOOK MACSYMA-UNTRACE-SUB PRED-$READ TSDIFF
            TRACE-EXIT-PRINT TRACE-EXIT-BREAK TRACE-ERROR-BREAK
            TRACE-ENTER-PRINT TRACE-ENTER-BREAK PEXPON*// $ALGTRACE
            LIN-VAR-FIND MONOMGCDCO $PFACTORALG PFACTORALG1
            LINHACKCONTENT PSHIFT PRESULT PGCDA PGSUBST RATGSUBST
            PRIMELMT PGCDU1 PSQUOREM1 RETFACTOR $ATVALUE TIMESIN TMS
            $DERIVDEGREE DIFFINT1 INTERVAL-LIST SIMPINTEG MSUM
            SAME-SHEET-SUBS PSCSUBST PSISIMP LIMIT-SUBS SUBFUNMAKES
            EASY-SUBS SIMPQUOT EXPPLYGAM-FUNS SETARG1 PLYGAM-CONST
            GAM-CONST PLYGAM-POLE MSIZE-TEXT-STRING CSEMIDOWN PSCOEFF1
            POLYINX RATTIMES INTSC1 INTSC PERIOD ARCHK SIMPEXPT LOGCPJ
            PSCHECK LOG*RAT FACTPLUS1 LOGCPI CSEMIUP PDIAG-ALL
            LIFTING-FACTORS-IMAGE INTERP-POLYS PINTERP NEWGCD MTORAT
            LOBJ->POLY INTSC0 GCD-DEGREE-VECTOR SIGNDIS1 POWERCOEFLIST
            PCSUBSTY MONICIZE-ROW FIXVL0 SWAP-ROWS ASSSO PARTIAL-DIAG
            SIMPLN RATTI SIMPATAN2 DIV-DEG-CHK ILT1 MYDEFINT LAPSINH
            LAPSIN REMFACTOR PROPSCHK DSKATOM $BEZOUT GCALL2$ AR$+AR$
            VMAKE $RESULTANT RESULT1 PCSUB INSRT HYPERTRIGINT1 EZGCD
            $LAPLACE RISCHEXPVAR ATFIND APPLY1 FINDEXPON Z1 GETEXP-FUN
            FINDFUN FINDBASE PART+ ATOMCHK PSCOEF SIMPNCEXPT MUL3 DISP1
            SIMPNCT TR-MPROG-BODY OUTER-CONSTANT LAMBDA-WRAP1 QUAD-SL
            SUBSTITUTEL VAR-EXPAND IPOLY2 CALL-AND-SIMP FPOLY2 KEYHOLE
            FACTPLUS0 MSIZE-NOFIX MSIZE-POSTFIX MSIZE-PREFIX
            MSIZE-INFIX SIMPPROD PUTPROP1 MSIZE-ARRAY MSIZE-PAREN
            MSIZE-ATOM EVAL-PRED MSZ MSIZE-NARY MSIZE-MATCHFIX
            MSZ-BIGFLOAT COEFF RATCOEFF RE-SOLVE MEASURE
            FACTPOWERSELECT BEHAVIOR-BY-DIFF EEZZ CONF2 SOLVENTH3
            SIMPLUS RECTZTO%PI2 LHOSPITAL M2 $RESIDUE PCETIMES1 COLEXPT
            PALGSIMP MAXIMA-SUBSTITUTE REFLECT0 DSUBSTA PDECRED
            BOTH-SIDE PCOEFADD ALLSUBST00 MINVARLIST-MRAT ISGEO1
            SIGNDISCR EVERYSUBST00 EVERYSUBST TMRATCONV SP2INTEG12 INTI
            SP2INTEG13 TMEXCHANGE PCSUB2 KANSEL SP3SUBST SPC5B PCSUBST
            $POWERSERIES EVERYSUBST0 CF SP2INTEG WTPTIMES TMNOMOREUSE
            SUBSTFORSUM EVERYSUBST1 RATDP2 AR$*S SP2DIFF1 SP2DIFF2
            TRAMP3$-M TRAMP3$-F SRATSUBST PELSO1 PSP2FORM TR-MASET
            DPREMQUO SP3SUBSTP1 SIMPEULER SIMPDERIV SIMPSIGNUM DPDIF1
            SIMPBERN TR-MACSYMA-USER-FUNCTION-CALL DEQF TFGELI0
            SIMPBUILDQ DIAGMATRIX MAKE-OPERATION REPLACEROW PART*
            SIMPFACT SIMPGFACT SIMPSUM BESSEL SIMPMDEFMACRO LINEARIZE3
            PARTITION FPSCAN SIMPTIMES FPINTEXPT DEFS1 ATAN-POLE1 BYDIF
            MLISTCAN-$ALL MACSYMA-TRACE-SUB INTCV2 MSZ-MQAPPLY
            TRACE-FSHADOW MSIZE-LIST MSZ-MDEF MSZ-MEXPT CPUT SMONOGEN
            MSZ-MTIMES GFACT MSZ-MCOND COEFSOLVE MSZ-MDO MSZ-MDOIN
            SOLVE MSZ-MPLUS PSDISREP2 INTCV3 $RATSUBST EXPSEC-FUNS
            ARRSTORE-EXTEND RES1 RESIDUE SIMP-%SINH POLELIST SIMP-%ACOT
            INTSUBS EXPASIN-FUNS SIMP-%ASECH SIMP-%ACSCH PTTS1
            SIMP-%ACOTH SIMP-%ATANH LOADFILE SIMP-%ACOSH AL1 ROOTADDUP
            NROOT1 PUTPROP SIMP-%ASINH COT-PLUS SIMP-%ASEC TAN-PLUS
            SIMP-%ACSC PINTERPOLATE6 SIMP-%ACOS SIMP-%ASIN SUBST41
            SIMP-%SECH SIMP-%CSCH SIMP-%COTH SIMP-%TANH ISOLAT
            SIMP-%COSH ASK-PROP PUT-MODE ASS-EQ-SET RATLOG PGCDP
            PGATHERCOEF NROOTS SIGNAL-MODE-ERROR SUPEREXPT DECLVALUE
            MONSTERTRIG WTPCTIMES1 DECLMODE STURMAPC WTPTIMES1
            VERIFY-AS-SUBR-ARGUMENT-LIST BOOLEAN-CONVERT RESOLVENT
            PASIMP1 MBIND E3PROG EPROGRATD MEVALP_TR 
            $ARRAYSETAPPLY MEVALP1_TR INSURE-ARRAY-PROPS
            STORE-INTERNAL-1D COLLISION-LOOKUP MPUTPROP INHERIT-PROPL
            MEMBERROOT BAKALEVEL1 BAKALEVEL SET-LBP-AND-RBP COMMONROOTS
            TRACEMOD1 PEXPTMOD CPBGZASS ZASSG SPC5 COEFVEC PRESULTANT
            NISLET NISTREEBUILDER TS-FORMULA PSCDIFF LTERMVEC COLOUT
            ADDVARDEG PRSNARY TFGELI1 MEVALP2 IS-MOR_TR IS-MAND_TR
            IS-MNOT_TR DSKDEFPROP MARRAYSET1$ INTERVAL-ERROR
            $INTERPOLATE_SUBR COLLISION-CHECK AVLINSERT $POISMAP
            POISSUBSTA TSPRSUM POISMERGEC POISMERGES POISMERGE MERGE11
            PSDISEXCNT SYMBOLIC-EXPAND POISSUBSTCO GET-LEXP POISMERGESX
            POISMERGECX MULTIPLE-%PI EXPTAN-FUNS A-ATOM TESTA
            TRY-LHOSPITAL-QUIT DVCOE COEFFP COEFFPT COEFFT ZEPOW
            USE-OLD-CONTEXT SIMPLIM$PSI SIMPLIM$LI TESTA* NEWVARMEXPT
            MKILL SIMPLIMSC MFACT DSTRB DRAW-LINEAR MABS-SUBST SINCOSHK
            SUBSCS SUBSC RATSIMP ADD2CSTR EXPFACTOR DEG-LESSP SIMP-%TAN
            IN-INTERVAL META-MPUTPROP META-PUTPROP ATAN-POLES LOGX1
            INTCV INTCV1 $MINOR MINOR SIMPMIN DIAGLIZE1 SIMPSQRT
            SIMPMQAPPLY SIMPMDEF SIMPMATRIX SIMPLAMBDA SIMPEXP LISIMP
            DISREP-MONOM ZTORAT SIMPBIGFLOAT SIMPARGS1 EXPLIST
    t        SIMP-LIMIT SUBSTINT GENNEGS NOUNLIMIT LIMIT-CONTEXT
            CHECKDERIV1 BEHAVIOR SCE-INT SUBFUNMAKE SIMPLIMIT
            $ROMBERG_SUBR LIMIT1 PTORAT TFGELI SIMP-%ATAN PIVOT
            DIMCHECK GET-NEWEXP&FACTORS DGRF $PUT SIMPABS TRY-LHOSPITAL
            CPA RADLIM DLSF SP1PUTBUC)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T) T) MAPPLY1 LIMIT2 SIMPLIMEXPT SP1ADDBUC Z2
            REMOV2 REMOV1 $CHANGEVAR MDEFCHK LIMIT ONEN $TMLIN TMLIN
            KILL2 TIMER-MLIST LAGRANGE3 LAGRANGE33 PSTIMES*2 ORDLIST
            SIN-COS-INTSUBS POWEROFX DINTEGRATE RES MERGE-SOL-LIN-Z
            ONE-STEP SIGNDIS3 TRIVIAL1 DEN1DEN1 DEN1 CASE0 POLFOO CASE1
            FACT2Z ZFACT PART1 RESM0 DSKSTORE MPROPSCHK DSKARY PHI
            GCTIMES CXERFARG PSMONSUBST COMPLETEVECTOR PROP1 CDIVID-SL
            SIMPPROD1 LOGNX2 DERIVAT COMDENOM1 METHOD-BY-LIMITS
            RESPROG0 INITIAL-ANALYSIS PARSE-INTEGRAND SOLVEX EXTEND
            GGRM1 ZMTORAT SOLVESPEC1 $DEFINT INTERPOLATE-CHECK
            DEFINT-LIST TAKE-PRINCIPAL $LDEFINT LIMFACT2 PCSUB1
            SP3SUBSTPN TMLATTICE EVERYPTERMS AR$GCALL2$ CFFUN
            SRINTEGEXPD CONF1 SUMSUM ATOMAT SIMPSUM1 SIMPSUM2 FREESUM
            DEFA1 DEFINT MSZNARY DECLARE1 DIFAPPLY MSIZE-FUNCTION LIMCP
            DINTBYPART COT-TIMES METHOD-RADICAL-POLY MONICGCD
            FANCYPOIS1C TAN-TIMES FANCYPOIS1S PSDP2 PINTERPOLATE5
            COMPATVARLIST REFINE RATROOT PEXPT2 ENPROG OTRACEMOD
            CPTOMEXP EVERYPTERMS1 MATOUT DSKGET DSKSETUP PSDERIV1
            PSFLOAT1  COEFFRET $TLDEFINT SUBSTPART-TRANSLATION
            COEFFTT SIMPLIMFACT SER0 MDATA COEFFPORT KILL3 SP2INTEG2
            MAKE-PARSER-FUN-DEF SOLCOEF GAMMA1 PWTAYLOR COMPATVARL
            FORMX POLES-IN-INTERVAL LIMIT-POLE $SETELMX SUBARGCHECK
            MAKE-LIMIT-ASSUMPTIONS SPDERIVATIVE1 NEWMAT COMPLEXITY/COL
            COMPLEXITY/ROW ZEROP/ROW MAYBE-BREAK SET-LINEINFO)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T) T) MLAMBDA EXPLOG-FUNS MAKE-ASSUMP MOVECOL
            INTSUM1 RATRAD MOVEROW CPA-INDETERM REMOVE1 SC^N
            OUTPUT-TEXT* MDEFARRAY XRUTOUT $EMATRIX BMHK TMUNPIVOT
            TMINOR PSDERIV2 EXPEXP-FUNS LINHACK SPARSE-LIFT ZGCD-LIFT*
            DENN NUMN CASEGEN TRUFAC COMPOSE MOSTPART EZ1CALL
            EXPPOLYCONTROL RISCHEXPLOG MPART GET-SERIES PFRNUM
            DECOMP-CHAIN PRINCIPAL-VALUE-INTEGRAL FAN SIGNDIS2 SBSTPT
            DEN1DENN NOCONSTQUAD DEN1NUMN NONCONSTQUADENUM DOSUM DIFFHK
            EXPCOT-FUNS DIFAP1 PSDP1 FANCYPOISSUBST CSCSEC-PLUS
            SINCOS-PLUS A-DEF-PROPERTY DECOMP-TRACE INFOSTORE MSIZE)) 
(PROCLAIM
    '(FTYPE (FUNCTION * T) NLEFT STRING-SEARCH $FORTMX
            REARRAY-AUX BATCH-EQUAL-CHECK PARTFRAC CHEKVALUE DELQ
            MARRAYSET *ARRAY ZL-REMOVE $MATCHFIX ZL-DELETE
            DISPLAY-FOR-TR MAPLIST_TR CL-*ARRAY SOLVABLE MARRAYREF
            LIST-REF PUMP-STREAM RENAME-TF $SUBSTITUTE FIND-CF1
            TRANSLATE-FILE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T T T T FIXNUM T T T T) T) PSEXPT1)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T T T T) T) PP-INTIR1 PP-INTIR1-EXEC
            MM-INTIR1-EXEC INTIR1-REF PM-INTIR1 MM-INTIR1)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T *) T) WARN-MODE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T T T T T T) T) DEF-OPERATOR)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T FIXNUM FIXNUM FIXNUM) T) DSUMPROD)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM FIXNUM T FIXNUM FIXNUM FIXNUM)
                T)
            DRATIO)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM T) T) X**Q1 POLYIZE)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T FIXNUM FIXNUM) T) D-MATRIX SINGP PRODHK)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T T T) T) PNS-INTIR3 TMPERMUTE TMMOVE
            PSMONSUBST1)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T T FIXNUM T T) T) PSEXPT-FN1 PSLOG1)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T T T T T) T) ZS-INTIR3 MPC NUMMNUMN)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T T T T) T) INTIR3-R0TEST INTIR3-REF
            DENMDENN DENMNUMN CSCSEC-TIMES SINCOS-TIMES MPC1 DIMNARY
            PSPLUS2 PSDIFF2 ZGCD-LIFT NUMMDENN FILL-ROW)) 
(PROCLAIM '(FTYPE (FUNCTION (T T FIXNUM) T) TB2 CPBG)) 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM FIXNUM) FIXNUM) DBA DBV)) 
(PROCLAIM '(FTYPE (FUNCTION NIL *) MBREAK-LOOP BREAK-CURRENT)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL T) PARSE-ERR $RESET MTERPRI RUNTIME
            EXP-PT-ERR ESSEN-SING-ERR TAY-DEPTH-ERR $TR_WARNINGS_GET
            $LOGOUT CONTINUEP SUPUNBIND FPPI1 TYI* FPONE $QUIT MFILE
            RESTORE2 RESTORE RESTORE1 POP-LOOP-CONTEXT NC-ERR GCCON1
            $PRINTVARLIST GENREF PRINCIPAL $CLEAR_RULES MAIN-PROMPT
            BREAK-PROMPT $CLI MACSYMA-TOP-LEVEL THROW-MACSYMA-TOP
            $CLOSEFILE ROMB-TIMESOFAR MSUBLIS-SETUP RECOVERORDER2
            MSUBLIS-UNSETUP RECOVERORDER1 MUNLOCAL BACKWARD PRINTLABEL
            DISPLAY* $ERRORMSG $CLEARSCREEN CONTEXT-UNWINDER PROPG FUU
            DQ- INFIN-ORD-ERR TMINITIALFLAG TMSORT1 TMHEADING DQ+
            COMPILE-FORMS-TO-COMPILE-QUEUE-NOW GCCON SET-UP-TRANSLATE
            TERPRI* NEW-COMMENT-LINE PRINT-TRANSL-MODULES NEW-ALG
            $UNORDER FIND-LISP-READTABLE-FOR-MACSYMA
            SET-READTABLE-FOR-MACSYMA GETRISCHVAR GETOPTIMVAR OPT-ERR
            NOR-ERR PRINTNET COMPILER-STATE NEXTK-SL NEW-END-SYMBOL
            CALCSC-SL QUADSD-SL CAUCHY-SL SCALE-SL NEXTH-SL CALCT-SL
            POLYEV-SL UPDATE-GLOBAL-DECLARES FORGET-GLOBAL-ASSUMPTIONS
            MAKE-GLOBAL-ASSUMPTIONS RESTORE-ASSUMPTIONS CONTEXTMARK
            KILLALLCONTEXTS CLEAR CLEARSIGN QUADIT-SL NEWEST-SL
            MATCHERR NILL GAUSS $LOAD_SEARCH_DIR
            INITIALIZE-$FILE_SEARCH CHAR-LIST-SYNTAX-ON
            CHAR-LIST-SYNTAX-OFF GENSUMINDEX FPPI FPE DIVERG KINDP34
            DBZ-ERR GOBBLE-COMMENT MAKE-PARAM PEEK-ONE-TOKEN SPC0
            INIT-BREAK-POINTS CURRENT-STEP-FUN RESTORE-BINDINGS $BT
            SCAN-MACSYMA-TOKEN UNFAM-SING-ERR PARSE-TYI PARSE-TYIPEEK
            SCAN-LISP-TOKEN SCAN-ONE-TOKEN GOBBLE-WHITESPACE DSKSAVE)) 
(PROCLAIM
    '(FTYPE (FUNCTION * *) SAVE-LINENUMBERS CONTINUE $FRAME
            BREAK-QUIT $SYSTEM)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) *) BREAK-DBM-LOOP LISP->LISP-TR-LAMBDA
            TR-LISP->LISP TRANSLATE-FORM  DETERMINANT1
            TRANSLATE-AND-EVAL-MACSYMA-EXPRESSION FASLP $UNKNOWN
            GETFUN-LT CSIGN FREE-LISP-VARS TRANSLATE-FUNCTION
        ))

(PROCLAIM
    '(FTYPE (FUNCTION (T) t) 
             MEVAL1 DETERMINANT1
             $BFLOAT CSIGN FREE-LISP-VARS
            *BREAK-POINTS* LIMUNKNOWN PFLOATP))
(PROCLAIM
    '(FTYPE (FUNCTION * T) $TLIMIT $LIMIT $DELETE $GCD LIMIT-LIST
            $EXPAND $RAT BARFO SUM-VAR-SETS TR-TELL $KILLCONTEXT
            MAKE-DISP-HACK-OB $FACTS $DEACTIVATE DEACTIVATE $ACTIVATE
            ACTIVATE FMAPL1 $GENFACT ADD* LISPM-MERGE-PATHNAME MTELL
            MUL* $SORT LINEL MAKE-BKPT STEP-INTO STEP-NEXT
            MAKE-LINE-INFO DBM-READ $SCONCAT $BACKTRACE TRACE-MPRINT
            ADD $RATWEIGHT $RATVARS $TAYLOR $FREEOF $MATRIX $REMAINDER
            LIMIT-NO-ERR $QUOTIENT $MOD $RATSIMP GET-LIMIT $FULLRATSIMP
            MAKE-MGENARRAY $UNTELLRAT $MAKE_ART_Q MCALL $POISSUBST
            $REALROOTS $ASKINTEGER $HORNER $NROOTS SCAN-STRING
            RETLIST_TR MAP1 $INTEGRATE FPMAX FPMIN $CONTEXT $RANDOM
            $MIN $MAX $TELLRAT $CONTENT $SCSIMP ERRRJF TR-GENSYM MUL
            $FACTOR $SUBMATRIX $FILENAME_MERGE $DEMO $READONLY $PRINT
            $READ $TRIGREDUCE MERRBREAK $BREAK CONCAT X$-CL-MACRO-READ
            $ALLBUT OUTERMAP2 MFORMAT $ERROR MFORMAT-SYNTAX-CHECK
            MFORMAT-TRANSLATE-OPEN $PAUSE $FACTOROUT AFORMAT MMAPCAR
            CONTEXT $BDISCR $ALGFAC $PERMANENT $NEWDET $TMLINSOLVE
            $TMNEWDET NPRINC* MREAD-NOPROMPT TYI TYIPEEK MREAD
            CURSORPOS $MULTTHRU $REMBOX $BOX $LPART $DPART $CONCAT
            $ADDCOL $ADDROW $GENMATRIX EXPO LAPPROD LAPSUM FACTOR $DIFF
            OUTERMAP1 SCANMAP1 $DIVSUM $DEPENDS $INPART $EZGCD $PART
            $DISPFORM $COEFF $APPEND LOAD-MACSYMA-MACROS-AT-RUNTIME
            $DISP $REST $LDISP ASS-EQ-REF MAKE-TSTACK-SLOT $DIVIDE
            $RATCOEF)) 
(PROCLAIM '(FTYPE (FUNCTION * T) D-VBAR)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM T) T) D-BOX)) 
(PROCLAIM '(FTYPE (FUNCTION * T) D-HBAR)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM T) T) MTOA RITEDIV)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T) T) COLROW0)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T T) T) MINORL)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T FIXNUM FIXNUM) T) X**Q ECHELON2 TRIANG2
            DRAW-2D NEWINV)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM) T) ZROW)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T) T) PACOEFP DISREP ATAN2NEGP ILT3 LAPDEFINT
            $SIGN ILT0 INCRLIMK ATVARSCHK FACT5 RAINV MOPP LAPLUS GETOP
            LAPLACE $MATRIXP FPENTIER LAPTIMES CPTIMESX WTPTIMES2
            REMSIMP $TRUNC CFACTOR HORNREP PUTODR LAPERF ELABEL INLIST3
            LAPINT DISP2 LAPDIFF MSPECFUNP CRECIP $PFET SSSQFR $REVERSE
            LAPLOG $DISPTERMS $TOTALDISREP SOLVECASE MEQUALP $FIRST
            SNUMDEN RULEOF EXPONENTIATE OPTIONP $ELLIPTK1 $LAST ROT*
            $LENGTH MNEGP $ELLIPTK $RATDISREP $ELLIPTE1 $RATP $ELLIPTE
            $ATOM $PRIME DERIV $TOTIENT $SYMBOLP RTZERL2 $ARGS IMODP
            LEADOP $NUM PMINUSP $RATNUMER DERIVDEG1 RISCHLOGDPROG
            EVTILDEGLESS PSUMSQ RISCHFPROG SUBGEN $GCFACTOR ATSCAN
            GCDISP AT1 LISTOVARSL RISCH-CONSTP ERECIP DECL-REALP
            MINLIST MAKE-SWITCH-LIST DONTFACTOR MAKE-LONG-LIST READLIST
            EVNUMP PFACTORANY PKRONECK $INTEGERP PS-INFP PFACTORQUAD
            MNLOGP REVSIGN $EVENP LISTOVARS0 $TAYLORP *KAR TAY-ORDER
            INCREMENT-TRUNCS EDISREP $NUMFACTOR SRDIS ORDHACK
            PSLOG-MONOM LIST-STRING SIMPLN1 MAXIMA-COPY-REST TESTTNEG
            MAKE-DEFINT-ASSUMPTIONS ZL-CHAR ORDER-LIMITS PSQFR
            EXTENDED-NUMBER-P I-$REMOVE *RED1 TSBASE-COMB
            MACSYMA-READ-STRING SFORX SEVN EVEN1 LI2NUMER TSEXPT-RED
            CHEBYLI2 SIN-COS-INTSUBS1 CHEBYS12 MAKNAM TESTP E1-
            CHEBYLI3 PARTITION-NS MNLOG OSCIP TESTT MGENARRAY-AREF
            MGENARRAY-ASET SUBFUNSUBS MGENARRAY-TYPE POLE-ERR
            MGENARRAY-NULL SUBFUNNAME MGENARRAY-GENERATOR SRCONVERT
            MGENARRAY-CONTENT EXPLODE |RETLIST-aux| EXPLODEC TANSC
            FUNCTION-ARRAY-P SCPROD STRING-FROM-CHAR-LIST PLYGAM-ORD
            SSP MAPATOM FPART LGCTIMES ABLESS1 LOGCONCOEFFP LOGCON
            REMBOX1 LGCPLUS LGCSIMP ZTO1 GEN-POINT BOX-LABEL LGCSORT
            THRAD CREATE-LOBJS BATAP CLEAR-LOBJS $COPYMATRIX BATAPP
            LGCSIMPLEP $SQFR $COPYLIST IGPRT $FIBTOPHI GGRM BATA0
            FREEVAR MAXCOEFFICIENT MAKE-LINSOLS NORM NISREMLET POLY->PS
            KILL1 FOR-EVAL-THEN-QUOTE NISPERMUTATIONS
            FOR-EVAL-THEN-QUOTE-ARGL TMLINSOLVE DECLARE-SNARF
            NISNEWLIST INVERT-TERMS PS-INVERT-VAR TMMAXP PSEXPT-FN-SING
            CMARK CUNMRK LOG-ABS-TVAR NISINNERNULL KILLFRAME NEG-MONOM?
            REMOVE-TYPE NISNUMBERPICKER NEWCON LIM-PLUSP
            ENSURE-A-CONSTANT-FOR-MEVAL NISEXTRACT EMIT-DEFUN NISKERNEL
            COMPILE-FUNCTION TVAR-LIM TLIST-MERGE MACSYMA-FSYMEVAL
            ORDER-VARS-BY-STRENGTH SRDISREP $LOGARC PSDISREP MEVAL*
            PSDISEXPAND MACSYMA-FSYMEVAL-SUB SETUP-MULTIVAR-DISREP
            DELETE-OLD-AND-OPEN $TAYLORINFO
            INSERT-NECESSARY-FUNCTION-DECLARES PRINT* PARSE-TAY-ARGS
            SUB-PRINT* FIND-TLISTS MOPSTRINGNAM FINDTL1 TRACE-FSYMEVAL
            PSDP PSFIND-S1 TRACE-PRINT PRINC* MICRO-TO-SEC PRINT-MODULE
            PRINT-TRANSL-HEADER MACSYMA-TIMER SP1TIMES SP1UNTREP SP1ADD
            MACSYMA-UNTIMER TRIGFP GCDRED PGCDEXPON NORM1 SP1TLIN1
            RDIS* GOOD-FORM BAD-FORM READ-COMMAND-TOKEN ALGPGET
            READ-COMMAND-TOKEN-AUX UCONTENT REMCOMPARY ALGNORMAL
            PRED-REVERSE PFACTOR1 RCONTENT CH-MINUSP OLDCONTENTA
            CONTSORT PARSE-NOFIX CHANGESIGN I-$STORE COEFL PCONTENTZ
            PARSE-BUG-ERR PSPLIT-FIELD INFOLSTCHK FINDSIGNOFACTORS
            DELIM-ERR MAXCOEF1 FILELENGTH NEWPRIME UNKNOWN FNEWPRIME
            LISTARGP $PRIMEP ATOMVARS ADJOIN-SING-DATUM PREMTERM-ERR
            LEADCOEFFICIENT *MMINUS RATWTSETUP $COS FIXEXPAND
            $LISTOFVARS TMS-FORMAT-PRODUCT FUMCHECK TSTACK-SLOT-P $ASIN
            PARSE-CONDITION NONEG TIMEORG $FLOATNUMP $DEBUGMODE
            MMINUSP* PARSE-$DO MAXLIST $POISSIMP PARSE-TAY-ARGS2 DISPLA
            PARSE-TAY-ARGS1 MAKELABEL TWOARGCHECK CHECKLABEL PFACTOR11
            OPERATORP GETOPR FACTOROUT CHECKFLAGANDACT EXTRACTVARS
            MOPSTRIP SIMPLEXPON TSTACK-SLOT-MODE MAXIMA-CONSTANTP
            TSTACK-SLOT-TBIND SIMPNRT1 ORD-VECT1 TSTACK-SLOT-VAL-MODES
            PSMINUS-TERMS TSTACK-SLOT-SPECIAL ZIREDUP LISTOF0S
            POISPZERO TAGIRR INTOPOISCO CHECK-OUT-OF-CORE-STRING HASVAR
            POLYST INTBASEHK $FACTORSUM $COSH POISMAP ONEVARP BASELIST
            NONZERP |MDEFPROP-aux| POISSUBST1C PMAKE ISO1 DDIV ARRFUNP
            POISSUBST1S ISO2 $SQRT FINDIBASE MGEN2 POISCHANGESIGN $SINH
            LCPRODL CFACTORW MATCHECK UNTREE PIRREDP UNTREE1 PRLAB
            FACTOR1972 POISENCODE $CSC FACTOR72 CHECKENCODE HASHER CNTP
            1P CSF $SEC POISCOSINE CONDENSE MULTFACT PAINVMOD SIMPLE
            POISNEGPRED $COT NEWSYM FPCONTENT PROPERTIES ALG $TAN
            POISDECODEC MAKPROD1 POSIZE DISPATVALUES $ATAN PUREPROD
            POISSINE DISPATOMGRADS DISPGRADEFS MLOCAL-AUX CSQFRP TRIMF
            DISPMATCHDECLARES PFLATTEN ARGSUBST MFACPPLUS SPLIT2
            $INTOPOIS PRIMCYCLO PFACPROD FACTXN+-1 CYCLOTOMIC
            POISSUBSTCO1 LOWDEG PSTRUNC MAKSYMP MAKSYM FACTXN-1
            LET-MACRO-GET-LAST-VAR POISCDECODE CHOOZP FACTOSIMP
            FACTXN+1 FACT5MOD GETSIGNL PABS DIVISORS CPBERL LOGTWO
            UNMRK PMONICIZE FRAC DINTNUM ESTCHECK %E-RIGHT-PLACEP
            $PRINTPOIS DINTERN KNOWN-PS %EINVOLVE01 NONPERIOD SEMANT
            ARRFIND POISDIF4 INTOPOIS DBNODE POISINT4 DB-MNUMP MARKS
            MARK MARKP NODEP PSPLIT-FIELD1 PRODND RFORM PLSOLVE
            GET-ARRAY-POINTER GAMMAFLOAT LMAINVAR DO-GAMMAFLOAT GAMMA
            PCOEFVEC ONEP1 ERF PSEXPON-GCD PASCAL PSFIND-S TMLATTICE1
            GAMMARED ADD-LINEINFO LIST-OF-MLISTS TMREARRAY $OUTOFPOIS
            FORM-MRAT FIND-STREAM PSEXPT-FN2 FORM-MEXPT RED-MONO-LOG
            FORM-MTIMES TSTIMES NEWVAR1 FORM-MPLUS $XTHRU RDIS1
            $RATEXPAND RATDISREPD PSEXPT-FN MARKND STRIPTIMES
            TMDEFARRAY RAT->PS ISTRENGTH |DSKSETQ-aux| SIGNDIFF RATMIN
            MEVALN HYPEREX0 MDEFLISTP FALSEP HYPEREX1 I-$REMVALUE
            GET-FREE-INDEX TRUEP ISMAX $SUMCONTRACT SUMCONTRACT1
            MDEFPARAM $BASHINDICES UNTRUE SUMCONSIMP TRUE* LINCHK
            REMRULE NUMDEN* $NICEINDICES REM-VERBIFY LOAD-FILE SER1
            MAKEALIAS IS-MOR POFX MEVALP RDFACT MAKSTRING SIGN CONSTLAM
            CASIFY-EXPLODEN FACTOR-IF-SMALL MPARAMS IS-MAND
            MREDEF-CHECK CARFILE SIGN1 PRINL SP1KGET REMPROPCHK
            REMOVE-TRANSL-ARRAY-FUN-PROPS REMOVE-TRANSL-FUN-PROPS
            IS-MNOT KILL-OPERATOR MACSYMA-UNTRACE GETLABCHARN SP1EXPT2
            SP1LOG2 $GAMMA VISIBLEP SP1TRIGEX BIGFLOATM* ADDLABEL
            AUTOLDCHK SP1TRIG NUMER DSKRAT NEGP COMPSPLT SP1LOG CSCH
            FORGET1 CSC MSETQP COTH HARRFIND COT ROOTFAC |:SPREAD|
            REMORDER ATAN1 POLYINT MQAPPLY1 MUNBIND SIGN-ODDINC
            POLYINT1 ASECH ADDMLIST ASEC POLYINT2 ACSCH BBSORTEQNS ACSC
            NPASK FSTRINGC PUTORDER ACOTH MNUMP ACOT ORDERPOINTER
            $EXPONENTIALIZE IS-BOOLE-CHECK %PIARGS-SINCOS CONSTANT
            OPTIMIZE-PRINT-INST LOGMABS PROCESS-MESSAGE-ARGUMENT DPROG
            LINEARIZE EVERYSECOND %PIARGS-CSCSEC SOLVELIN SQRTX^2-1
            ROUNDRHS LIN-MEXPT $LISTP LIN-MTIMES PRE-ERR LIN-MPLUS
            MIDPNT SQRT1-X^2 RHALF SQRT1+X^2 KILLVARDEGSN SEC
            SCAN-NUMBER-EXPONENT CONSTACL PCONSTP MAXCOEF
            SCAN-NUMBER-AFTER-DOT DBZ-ERR1 SCAN-NUMBER-BEFORE-DOT
            OBTAINABM POS OBTAINAB TAYAPPROX %PIARGS-TANCOT MAKE-NUMBER
            CPBER1 ROUNDROOTS1 FIXUPREST MHEADER LINOUT
            PFREEOFMAINVARSP IREDUP FIRSTCHARN RATDENOMINATOR $RADCAN
            PFLAT1 ALGSYS GETUNHACK ALGSYS0 KNOWNFACTORS LOFACTORS PGET
            OP-SETUP $COMBINE MSTRINGP FRPOLY? CALLSOLVE CHANGEVAR
            TRACEMOD PARSE-PREFIX SIMPLEXP RPOS RATNUMERATOR
            MINIMIZE-VARLIST LFIBTOPHI PMINUS MEMQARGS RADCAN1
            FIXEDMATCHP MONIZE D-PRODSIGN PMOD EMIT MAKESTRING
            SORT-POLES GFSPLIT FMP1 LINEAR-DISPLA ATOMSON RMCONST1
            NMTERMS PROC-$DEFMATCH PRINCIP FLMAXL ALLATOMS P*PIN%EX
            FLSORT PROC-$TELLSIMP PIN%EX SPC7 %TO$ D-SUMSIGN
            PROC-$TELLSIMPAFTER RJFSIMP PROC-$DEFRULE
            PROC-$MATCHDECLARE SUBFUNARGS %ETOLOG TRANSPOSE-ELS
            NISLETSIMPRAT $NONSCALARP ZEROLP DISREPLIST1 REPLIST1
            NISLETSIMP INTSET1 EXACTONLY $ECHELON NEWVARMAT1 CALLAPPRS
            CHECK SIGNUM1 RFLOT RISCHFORM PUNIVARP $ODDP FINDLEASTVAR
            INTEGERP2 KILLVARDEGSC RATSQRT GETALIAS RISCH-PCONSTP
            GETVARDEGS MMMINUSP PTIMEFTRS FIXINTGREAT NO-SING-ERR
            SUBVAR SCAN-TOKEN FILENAME-FROM-ARG-LIST DISTREP RAT1
            CONDENSESOLNL EPROG CHECK-DIMSTRING $WRITEFILE SRCONVERT1
            RATFIX D-INTEGRALSIGN FILESTRIP RISCHLOGEPROG TRIG1 LPOS
            SIMPLIMPLUS1 PSDISEXTEND RAT8PRIME RBP $ED COMPLEXNUMP RAT8
            SET-UP-CURSOR LBP INTFACTOR CONDENSESUBLIST SIMPLOG
            CONDENSEY SIMPAB COMBINEY INTEGRATE1 HLINSOLVE APROG
            ALIASLOOKUP RISCHLOGPOLY PTERMVEC HIDELIMA
            MAYBE-BOOLE-CHECK SUM-OF-INTSP FASPRIN SUBST10 LISTGCD
            SIN-SQ-COS-SQ-SUB PARSE-MATCHFIX RAT10 MEVAL SIMPLIM%ACOSH
            CHECKSIGNTM REMABS UNSTOREP  RIDOFAB
            MARRAY-TYPE LEADARG FANCYPAC $SECH
            GETFNSPLIT GVAR-LOGP INTEGRALLOOKUPS MAKNUM SIMPLIMTIMES
            EXPLODEN ZEROP2 $SIN GETMINOR HALVE DILOG GET-LINEINFO
            $COTH SEPARC LIM-IMAGP INTFORM MARRAY-TYPE-UNKNOWN RATLIM
            PNEXT1 SUBSTINT1 PQR TRUE FANCYPAS TLIMP $TANH RISPLIT
            TAYLOR_SIMPLIFIER_CALLER GETLIMVAL SET-FULL-LINEINFO CV
            DENOMFIND RATFNT SIMPINF LOAD-AND-TELL ABSARG $LISTARRAY
            LINE-INFO-LINE SUBST4 $POISSQUARE ABSARG-MABS BKPT-FILE
            TO-MACSYMA-NAMESTRING REFLECT BKPT-FILE-LINE LISTARRAY
            SIMPLIM%ATANH SET-ENV LIM-MINUS COVERSINEMYFOOT P11 TANSC1
            MACSYMA-NAMESTRING-SUB $CABS MQAPPLYP ADD-UP-DEG
            INSERT-BREAK-POINT STURM $CARG ERRSET-NAMESTRING
            |$MDEFVAR-aux| TSPLUS FORWARD SHOW-BREAK-POINT FULLSTRIP
            $TRIGEXPAND REMOVE-BINDINGS RE-TAYLOR NBN FULLSTRIP1 DSRL
            COMPATTLIST ARGNUM MACSYMA-NAMESTRINGP NUM-OF-LOGS
            OPEN-OUT-DSK COMPLEXITY OPEN-IN-DSK NUM-OF-LOG-L LIM-LOG
            RISPLIT-MPLUS ELEMXPT SIGN-MPLUS VARP RISPLIT-TIMES
            ASK-INTEGERP SIGNFACTOR STURMOUT $SHOW_HASH_ARRAY LIM-EXP
            SIGNSUM FINDINGK P1 RATNUMP MIDOUT UPRIMITIVE $BATCHLOAD
            SRF SRATSIMP FINDS SUPERTRIG BKPT-FORM WNA-ERR
            BKPT-FUNCTION SUPERSINX LINE-INFO-FILE PWEIGHT LIM-ABS
            SUPERCOSNX $NUMBERP PDEGREER MAXIMA-INTEGERP LEADTERM IR
            TRIG2 EVOD MAKPOINT UDM-ERR MAKRAT RATIONALIZER MTIMESP
            PMODCONTENT UNIPOLY COMBINEY1 MULTOUT CHECKDERIV PARTFRACA
            MSEEMINGLY-UNBOUND ROOT-BOUND ERRLFUN1 OPTRIG PGATH3
            IR-OR-EXTEND SINNX PGATH1 COSNX POSEVEN BIQUADRATICP
            WTPTIMES3 BIQUADP1 TRANSLATE-PREDICATE TRIGFREE SOLVECUBIC
            RATS ROUND1 TRP-MLEQP ADISPLINE F3 TRP-MLESSP COMPLICATED
            ARCLIST MAXIMA-RATIONALIZE TRP-MGEQP ARCFUNCP TRP-MGREATERP
            SOLVEQUARTIC ODD1 TRP-$EQUAL SUBVARDLG TRP-MEQUAL SIMPLIFY
            LEADALGCOEF FPROG SSIMPLIFYA MMACROEXPAND1 MPLUSP INFSIMP
            FPEND FPATAN NDM-ERR NSM-ERR REM-CONST $SUBVARP LINEARCONST
            FPFORMAT REM-OPERS-P FPROUND TANBIGFLOAT IA-ERR LOGBIGFLOAT
            FPLOG ATANBIGFLOAT MABSBIGFLOAT COSBIGFLOAT DEFA DEFS
            SINBIGFLOAT DEFC FPPOSP DEFC1 FLOATTOFP FIXFLOAT
            ADDBIGFLOAT MODE FPEXP MODEDECLARE-INTERNAL RATBIGFLOAT
            MFUNCTION1 ZEROP1 FPEXP1 FINDP $TRACE_IT TBF MSTRING
            MACSYMA-TRACE FORTSCAN NEG FORTSCAN-MTIMES $UNTRACE_IT
            IMAG-ERR BBSORT1 BX**N+A SAVEFACTORS FINDSUB LOGRED BX**N
            MEVENP $SUM-AUX SAVEFACTOR1 STRSYM FREE1 PRIMEP TDPN $ACSCH
            FINDIT LIM-RECIP TDPOS SCAXN MRETURN SIMPLERD MAKPOLY
            TBOUND-FREE-VARS $MAPATOM TDZERO RATREP* TR-ARGS STRMDO
            STIRLING0 DATUM-LIM DBZS-ERR GENPOLY $ASECH TAYCHK2RAT E1+
            STIRLING DELETMULT TRANSFORM-EXTENDS DEG ALGP STRMDOIN
            DTRANSLATE $EXP EXPPOLY REALONLY MODDP SUM-C*LOGS
            FUNCLOGOR%E RDSGET OPERATORP1 $EXTENDP COEF-SIGN COMPSPLT1
            FLUIDIZE APPRSYS ZP $ACOTH QUOTED-SYMBOLP ALGSYS1 RDTAY
            LOGNXP SPLITPROD $ATANH TELLRATDISP MYCABS
            FOR-EVAL-THEN-MQUOTE-SIMP-ARGL $LOG SPLITSUM CABS PDISREP+
            MMAPEV TR-ARRAYCALL PSEXPT-LOG-ORD SYMBOLS PDISREP
            FACTORNUMBER PFACTOR TRANSLATE EXP-C*LOGS WHICHFN MRATEVAL
            COMPSPLT2 PZEROP EVOD-MPLUS $ACOSH NFORMAT-CHECK ASIN
            $ASINH EVOD-MTIMES ACOS PSMINUS RPTROUBLE ASINH $ACSC
            JOINVARLIST ACOSH $ASEC RATMAX ATANH $ACOT CG-TYO-N MOD1
            LMUL TSEXP-COMB CG-TYO MARRAY-CHECK DBVARP ANTIDERIV
            SIMPLIM%ATAN $ACOS SAV&DEL MEVALATOMS CG-IMAGE-TYO-N SECH
            CG-IMAGE-TYO $GFACTOR RAT0 MMACROEXPAND IND2 MEVAL1-EXTEND
            LITTLEFR1 POLFACTORS TYO* MEVAL-ATOMS NMR C*LOGS NEWVAR3
            NRETFACTOR1 SIMPLIM%ASINH MEVALARGS TRISPLIT $CSCH
            SIMPLIM%TAN PSCONST PUTONVLIST NRATFACT SIMPLIMLN REPLAC
            EVFACT COMPSPLT-EQ GEN-TR-LAMBDA PDISREP*CHK CONSTTERMP IND
            SPECDISREP MLOGP SPECREPP UNMRKS FACTS1 SIMPLIMPLUS
            UNION-VAR-SET $DISTRIB ODNUMP SEMANTICS
            PATCH-UP-MEVAL-IN-FSET PDEGR ISUM LAB KILLC ASYMREDU REMOV
            TELLRAT1 TR-LISP->LISP-DEFAULT PORDER TR-LISP->LISP-FUN
            UNDEFINE-SYMBOL MCX UNRAT FIX GENSYM-READABLE
            MACSYMA-SPECIAL-OP-P *DEFINE-INITIAL-SYMBOLS DISREPLIST
            SP2EXPAND MAPTR-LISP->LISP CHECKRAT MINIMUM RADSORT REPLIST
            RAISE MAKE-VALUES SORTGREAT SIGN* LOWER DET1 FR-ARGS
            OBJECT-FOR-DISPLAY-HACK DEFINE-SYMBOL TREEDET ZERO-LIM
            J[1]-BESSEL STRIPDOLLAR $J1 FORQ UNTRANS-OP FACTORALG
            ECHELON1 CHECK-SUBR-ARGL TR-EXP-TO-DISPLAY POS-NEG-P
            DINTERNP $SHOWRATVARS $IMAGPART CSTRSETUP SIGN-MTIMES
            SOLVE2 $REALPART CREATSYM SIGN-ANY LIMUNKNOWN1 LNEWVAR ALBK
            $J0 %EINVOLVE LNEWVAR1 RATION1 TRIANG RGET
            TR-INFAMOUS-NOUN-FORM LRDTAY DET PREPFLOAT $NZETA EXPP
            MACSYMA-SPECIAL-MACRO-P MEVALP1 I[1]-BESSEL ISP $I1
            GET-LISP-FUN-TYPE CHECK1 $NZETAR CONSSIZE DOUTERN $NZETAI
            TR-NOSIMPP SPEC DCONVX ASKSIGN-P-OR-N
            POSSIBLE-PREDICATE-OP-P RESTORE-FACTS TRANSPOSE DATUM
            $IDENT $NOUNIFY $NEWCONTEXT $DETERMINANT MAXIMUM MNCEXPTP
            MNCTIMESP QUOTED-ARGS-AUX $SCALARP |INCLUDEF-aux|
            ARRAY-TYPE $INVERTMX INVERT1 MXC BIGNUMP $RANK BIGP
            RATINVERT $TRIANGULARIZE MAKE-EQUAL-HASH-TABLE ARRAYDIMS
            MMINUSP FACTORIAL FIXNUMP MAKEGAMMA1 ONEARGCHECK TOTAL-NARY
            $ENTIER IMPLODE MEXPLODEN FORGET ASSUME RESIMPLIFY OPIDENT
            MQUOTEP EXPINT AIRY G[0]-BESSEL I[0]-BESSEL $EXPINT $LOAD
            J[0]-BESSEL $FILE_TYPE $G0 $AIRY G[1]-BESSEL FILETYPE-LIST
            $I0 $G1 MFILENAME-ONLYP NONINTEGERP SAME TMKILLARRAY
            RZCONTENT FFIB $INTOSUM TM$KILL PCONTENT TMPIVOT-ISOLATE
            FNEWVAR MAKCF SP3RECONST FULLRATSIMP CFMAK DISTREXPANDROOT
            SP3FORM1 EXPANDROOT GOODFORM RATF RALGP INTEGERPFR FLEVENP
            TMACCESS CFEVAL SERIESEXPAND* TIMESTEST PALGP PMM-1
            FLOATFACT CFSQRT SP2LOG MONOM->FACL MEXPTP R1M CFRATSIMP
            SP2EXPT RATALGDENOM BIGFLOAT2RAT RATEXP RATDP $BFLOATP
            SERIESPASS1 TRP-MNOTEQUAL SHOW-EXP TRP-MOR SQCONT SP1
            PFLOATP1 EVALQUOTE TRP-MAND OUT-OF ORD-VECTOR MAXNORM
            TRP-MNOT |M-TLAMBDA-I-aux| AUGMULT $ISQRT
            |FUNGEN&ENV-FOR-MEVALSUMARG-aux| TR-UNTRACE FUNTYPEP
            |FUNGEN&ENV-FOR-MEVAL-aux| SP2TRIG DECREMENT-TRUNCS $QUNIT
            MAPCAR-EVAL SANDMAP TSLOG GETFACT |TRD-MSYMEVAL-aux|
            CONSERVE-EVAL-ARGS-DATA PSLOG TR-TRACE-HANDLE GGCD
            REMLABELS GETSUBR! $EULER STRING*1 EXLIST RCCOEFP TR-TRACE
            $BOTHCASES TRAMP1$-M EULER RATMINUS SRBINEXPND
            INVERTBIGFLOAT DPREP TSTIMES-L-MULT DPDISREP FPARCSIMP
            TRAMP1$-F GENERIC-AUTOLOAD EVFAC1 ADJOIN-TVAR MTO-FLOAT
            ARCP $CFEXPAND CFEXPAND TRIGP DPSIMP FILEPRINT
            LISPM-MARRAY-TYPE $FACTCOMB FEXPRCHECK $MINFACTORIAL *FPEXP
            CONSTFUN DOLLARIFY-NAME UFACT-STRIP-ZEROES FACTCOMB1 BCONS
            REDUCE-VAR-SET FILENAMEL %ITOPOT FACTCOMB BIGFLOATP DPDERIV
            LIM-FINITEP RATDISREP $DSKGC KDR ADJOIN-PVAR SIMPNCT-POWER
            DPSQFR COMPPI $RATNUMP $BERN KEY-VAR-POW NOTLOREQ KAR
            ERRBREAK SPECIALP BERN FLIP MAXIMA-FLOAT-PRECISION
            FREE-LISP-VARS-OF-ARGL PROCESS-ERROR-ARGL SCALARCLASS-LIST
            DOLLARIFY RE-TAYLOR-RECURSE SCALARCLASS CONSTP
            PUSH-PRE-TRANSL-FORM DOT2L INFSIMP* DFLOAT ADSUM ERRBREAK2
            IPOLYSUM RADMABS SIGN-POSFUN ZERP DENOM1 POP-PW GENEXPANDS
            IMPLIED-QUOTEP ZEROEQUIV1 TRUEFNAME IPOLY1 NUM1 INTOFP
            ARRAY-MODE-@ MAKE-VAR-SET MTRUENAME RPOLY-SL RULECHK
            FPINTPART $ASKSIGN MFILE-OUT DCONV-$FLOAT ZEROEQUIV2
            FPRATION1 FXSHFR-SL TBOUNDP EVOD-MEXPT $MAKEFACT
            EXPANDTIMES ERRBREAK1 ADUSUM ABSARG1 TR-CLASS
            FREE-LISP-VARS-M-TLAMBDA SIGN-MABS MAKEFACT1
            FREE-LISP-VARS-M-TLAMBDA&ENV $MAKEGAMMA KILLCONTEXT FPMINUS
            CPOLY-SL RISPLIT-EXPT $CFDISREP ASKSIGN01 TBIND FXSHFT-SL
            FPCOS1 CFDISREP1 AMPERCHK SHOW-MSIZE EPS-SIGN VARIABLE-P
            FPSIN1 NOSHFT-SL SPABS ELEM MSIZE-PRINT ASKSIGN1 I-$GRIND
            NUD-CALL BAD-VAR-WARN ERRLFUN VRSHFT-SL RISPLIT-NOUN _EVAL
            $VERBIFY SIGN-PREP STRMEVAL FPABS WARN-UNDEFINED-VARIABLE
            $STATUS-AUX SUSUM1 $POLARFORM $DESCRIBE TIMESBIGFLOAT
            EVAL-FOR-DECLARATIONS TRANSLATE-ATOMS MAKSTRING*
            TRANSLATOR-EVAL 2PISTRIP FUNCTION-MODE INTP
            FIXNUM-CHAR-UPCASE $%TH CONTROL-CHAR TR-WARNP 2PIREC
            DEMOIVRE INTP-MEXPT STRGRIND TUNBIND MPAUSE $DEMOIVRE
            MUNFORMAT STRPRINT ASKSIGN DECL-COMPLEXP SIGN01 MRATCHECK
            $THROW TUNBINDS $RECTFORM $TAYTORAT LISTOVARS1 STYO
            RESTORELIM SRRAT MAXIMA-STRING $RHS RUBOUT* $DENOM MBAGP
            SIGN-MEXPT TRIG-SUBST-P $LHS REMOVEALG NFORMAT
            CF-BACK-RECURRENCE TDNEG VARSORT $RATDENOM %ESPECIAL
            PMODROOT SRRAT2 $FIX $PAGEPAUSE FLOAT2RAT TDPZ SUMI TRIGRED
            PMODROOT1 SCONVERT SLASH HYPEREX SOLVE-SIMPLIST CFMIN PIP
            POLYFORM LOG-IMAG-0-2%PI FMT FACTRAT ALPHABETP NUMDEN ESAP
            EVEN TRIG-NOT-SUBST-P SQRTINVOLVE LOWERHALF
            %E-INTEGER-COEFF MTOSC PDIS ISUM1 POLYP INFR PIN%EX0
            FACTPLUSCOMB %I-OUT-OF-DENOM PRODNUMDEN REMC ROOTSORT
            UPPERHALF LOGQUAD0 SOLVENTH1 PDEGREEVECTOR SPECASEP LOGQUAD
            GETFACTORIAL NEWVAR FACTEXPAND LEADING-COEF
            LOG-RED-CONTRACT SKR MAXI $FIB SINRX PMINUS1 RAT-NO-RATFAC
            PMONZ REMRED OLDCONTENT LOG-REDUCE $ZETA SOLVEQUAD GETEXP
            ALGCONTENT PDECOMP* FACTCOMBPLUS LIMINV SPC4 NPLUS SPC2
            LI3SIMP FACTORLOGS LI3NUMER FPOLYSUM FASTCONT FREEVNZ
            MULTIPLY-GCFACTORS SPC1 LSA LI2SIMP OLDGCDCALL M$EXP?
            PTERMCONT FPOLY1 NEWGCDL MPGET FINDINT CLEAN-LIMIT-EXP
            FINDPOWERS1 ALGORD $OPTIMIZE PUTONLOGLIST CHECKPOW ISGEO
            NUMBERINLISTP GETEXPLIST *RULECHK CONSTCOEF OPTIM
            PDERIVATIVE2 MFBOUNDP RDIS NOTERMS VAR-OR-CONST COMEXP
            SPC2A I-$DEPENDENCIES HIDE COLLAPSE SPC2B LISTOVARS
            $TMINVERSE OPFORMAT ASKINVER CDISREP PDECPRIMEP PDIS*
            *TMREARRAY FINDBE PDECGDFRM #+gcl COMPILER::FN-P SP2INTEG1
            OPMEXPT CHECK-INF-SING FACMGCD TAN APPLY2HACK SINH
            $COLLAPSE COSH NFORMAT-ALL TANH DISPRULE1 OLDREP
            #+gcl COMPILER::FN-NAME CONSRULE #+gcl COMPILER::FN-DEF
            PROCLAIM-PROPERTY #+gcl COMPILER::FN-VALUE-TYPE SUBST1
            #+gcl COMPILER::FN-FUN-VALUES PSFLOAT #+gcl COMPILER::FN-CALLEES
            AT-SUBSTP #+gcl COMPILER::FN-RETURN-TYPE MULTIDEG
            #+gcl COMPILER::FN-ARG-TYPES NEWREP #+gcl COMPILER::FN-NO-EMIT OPTIONS
            #+gcl COMPILER::FN-MACROS DOWN SPECREPCHECK ADJOIN-DATUM
            MAP-EVAL-FOR-DECLARATIONS DECODE RENUMBER-TLIST MENU DOWNS
            UP TAYLOR3 UPS MARGS TAYLOR_SIMPLIFY_RECURSE SUBC-INTERNAL
            MOP TAYLOR2 SUPC-INTERNAL $FLOAT PREP1 FP2FLO FACTORSUM2
            FPCOFRAT VALUE-MODE FACTORSUM1 TEVAL $GFACTORSUM
            PARTITION-PRODUCT DCON PRODUCT-WITH-INNER-SCALARP COMBINE
            WARN-PREDICATE PSLOG2 SIMPNCT-SC-OR-CONST-P PSLOG3
            TRANSLATE-MACEXPR-TOPLEVEL IDENTITYMX DELSIMP
            TR-MDEFINE-TOPLEVEL MXORLISTP1 FORMAT1 TOPLEVEL-OPTIMIZE
            SIMPNCT-INVERT TR-SEQ $DEL TOPLEVEL-OPTIMIZE-1 STOTALDIFF
            DCONV-$CRE DIFF%DERIV PS-LIM-INFP LIM-INFP MOPP1 EZEROP
            TRFAIL PS-GT TR-MFUN GVAR-LIM TRANSLATE-$MAX-$MIN SUBST2
            TRANSLATE-ATOM $ALLROOTS SIMPNCT-ONEP LIM-ZEROP ARRAY-MODE
            DISPLINE SIMPNCT-ASSUMESCALARP SIMPNCT-CONSTANTP TVAR?
            ARRAYFUN-MODE CPOLY-ERR SIMPNCT-BASE FUNCTION-MODE-@ MEQHK
            STRING* ADD-POINT $TRANSPOSE DEGVECDISREP PMINDEGVEC
            I-$UNSTORE ODDELM MFILEP UNIVAR GCDL NON0RAND UNQUOTE
            FINDSIGNOFTHEIRPRODUCT $CONSTANTP CGCDLIST $ROOTSCONTRACT
            RTCON DROPTERMS RTC-GETINFO SETQMODULUS TMEVAL LEFT-OB
            ASCII-NUMBERP RIGHT-OB INTEGERP1 META-OUTPUT LGCCHECK
            $LOGCONTRACT ZEROHK ZEROSHARP MXORLISTP REMLAPLACE IS
            CONSTA $NTERMS)) 
(PROCLAIM
    '(FTYPE (FUNCTION * *) MFUNCALL APPLICATION-OPERATOR $EXAMPLE
            MACLISP-TYPEP)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM T FIXNUM) T) STORA)) 
(PROCLAIM '(FTYPE (FUNCTION (T FIXNUM FIXNUM FIXNUM FIXNUM) T) OBMTRX)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T T) FIXNUM) BEHAVIOR-NUMDEN
            DETERMINE-LIFTING-FACTOR)) 
(PROCLAIM '(FTYPE (FUNCTION (T (VECTOR T)) T) WALK-GET-LINEINFO)) 
(PROCLAIM '(FTYPE (FUNCTION (FIXNUM T FIXNUM) T) CPTOMF)) 
(PROCLAIM
    '(FTYPE (FUNCTION * T) BREAK-FUNCTION BREAK-STEP-INTO
            BREAK-STEP-NEXT CREATE-LIST1 $MAKE_ARRAY TEST-BATCH
            LISPM-REARRAY LIST-VARIABLE-BINDINGS MERROR $NOFIX $NARY
            $INFIX $POSTFIX $PREFIX MREAD-SYNERR HEXPAND MREAD-RAW
            HREDUCE MAXIMA-DRAW-FORM $SETUP_AUTOLOAD MAXIMA-DISPLAY
            POLYLOGP RISCHNOUN *MAKE-LIST TRANSLATE-FROM-STREAM
            $TRANSLATE_FILE ASK-CHOICEP ALTER-PATHNAME $COMPILE_FILE
            REMALIAS TYO ZL-MAKE-ARRAY WARN-UNDECLARED TR-LOCAL-EXP
            CF-CONVERGENTS-P-Q QUOT $BATCH BATCH $SOLVE GET-ARRAY
            TR-NARGS-CHECK MAREF1 WARN-FEXPR WARN-MEVAL TR-LAMBDA
            TR-FORMAT MAPATOMS SORTCAR *REARRAY FORTRAN-PRINT
            $FILE_SEARCH)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) *) RETRIEVE1 PRINT-ONE-FRAME TESTDIVIDE
            RECUR-APPLY OPER-APPLY ARRSTORE ASSIGN-CHECK TRY-EXPANSION
            PNTHROOTP LOAD-FUNCTION SP1EXPT TRACE-APPLY
            APPEARS-IN EZTESTDIVIDE)) 
(PROCLAIM '(FTYPE (FUNCTION (T T T) *) ARRFUNCALL))
(PROCLAIM '(FTYPE (FUNCTION (STRING T) T) GRAB-LINE-NUMBER)) 
(PROCLAIM
    '(FTYPE (FUNCTION (T T) T) DIM-MNCEXPT SININTP
            DIMENSION-SUPERSCRIPT MAP2C SHEUR1 DEPENDSALL DIM-%PRODUCT
            PRODCOEF SC-CONVERG-FORM DIM-RAT INVOLVE DIM-MQUOTIENT
            COMPILETIMES ZTO%PI2 DIMENSION-LIST COMPILEEACH UNITCIR
            LIMROOT IS-A-POLE COMPILEMATCH STARDISP REAL-ROOTS
            RADBYTERM META-ADD2LNC META-FSET COMPILEATOM GETDEC
            MAKEPREDS DEFMATCH1 COMPILEPLUS NTHCOL NCMULN CDRAS
            SIMPNCT-ANTISYM-CHECK SIMPNCT-MERGE-PRODUCT NONVARCHECK
            *UNION-MODE SIMPNCT-MERGE-FACTORS LIM-POWER SIMPNCT-ALIKE
            CHAINRULE SCALAR-MATRIX-PRODUCTP SDIFF
            MATRIX-MATRIX-PRODUCTP ATOMGRAD COMMUTATIVE-PRODUCTP
            DEPENDS SCALAR-OR-CONSTANT-P DEPENDSL DECMODE-ARRAYFUN
            ZERO-PRODUCTP SDIFFTIMES SDIFFGRAD MFREE SDIFFMAP
            STRONGER-VARS? READ-ONLY-ASSIGN _F PUSH-PW DCONV MGRP RATCF
            PUSH-DEFVAR SUBSUM TR-DECLARE-VARMODE CMOD-SL ERREV-SL
            ASSOLIKE ISLINEAR $PARTITION SPEXP SUBIN
            TRANSLATE-MACEXPR-ACTUAL LISP-FCN-TYPEP FIND-CF RATGREATERP
            SPANG1 SRRAT3 ASSQR RATPLUS ANDMAPCAR ANDMAPC GENFIND
            DINTLOG COMDENOM DYPHEYED SOLVENTH E+ MERGESOLN SOLVENTHP
            *MREAD-PROMPT* PSPLUS PEXPT E= CPOL2P PPLUS PMODREM SUMCOEF
            PRODCOEF1 BOTHPRODCOEF DIM-%INTEGRATE ARGSFREEOF
            DIM-%DERIVATIVE FLRED DMDERIVLONG FINDSES DMDERIVABBREV FR1
            DIMENSION-PREFIX FLGREAT FLGREAT1 RECONC LINDEP PGCD1
            DIM-%AT NISBUILD DIMENSION-POSTFIX LET-RULE-SETTER NISADDON
            DIMENSION-NOFIX DIM-MPLUS PSCOSHA+B PARSE-POSTFIX
            DIMENSION-MATCH DIM-%SUM PSTANHA+B SUBSETL DIM-%LIMIT
            EBAKSUBST PSDIFF1 DIM-MCOND ROOTSP HSIMP DIM-MDO DIM-MDOIN
            PARSE-INFIX DIM-MABS DIM-$MATRIX PARSE-NARY MGETL ADD2LNC
            HDOT MAPPLY-TR HSIMP1 FASPRINT PRADD2LNC PRSMATCH
            MARRAYREF1$ ERB-ERR MAKE-ALAMBDA MYADD2LNC SAFE-ASSOC
            SININT* PARSE TCONS COSINT* PEEK-ONE-TOKEN-G
            SCAN-ONE-TOKEN-G $ARRAYAPPLY POISMERGE22 DIVL POISCOINTEG
            PDIFROWS PDIFFERENCE PCTIMES PTIMESROW PTIMES AVLINIT
            REDRESULT CPBG0 PGCDU PSDISREP+ $POISCTIMES STRIP-ZEROES
            RATDERIVATIVE POISCTIMES1 NCDR EDIFF POISMERGE2 ATRIGH
            $POISTIMES $POISPLUS $POISEXPT PDEGREE INTERSECT* BPROG
            FIXVL1 POLYSUBST BOX INCREASELIST SQFRP HACKIT NTHELEM
            CREATENAME AFIXSIGN WTPEXPT LAPSHIFT PGATH2 $CONS LAPDELTA
            HORN+ RATDIVIDE $RATDIFF $ENDCONS PFET1 RESM1 NSUBSTRING
            $MEMBER LAPEXPT ISQUADRATICP EXTOPCHK RESPROG RAISEUP
            DEPENDS1 NONSYMCHK DIFFLAPLACE DIFFINT DIFFNCEXPT CPRES1
            ADD2* $SN PPLUSCHK ADD2 $AM DIFF-%AT $CN DIFFSUMPROD $DN
            GCALL1$ BEZOUT RATDX PRESIGN $AM1 GCTIME1 GETD0 SUBRESULT
            NEWGCDCALL DIVSUM $POLY_DISCRIMINANT TRIGIN1 IMODP1
            TRYRISCH JACOBI RISCHADD NONSQFRCASE $JACOBI PSUMSQ1 EVMAP
            BBSORT GCFACTOR PTIMESMERGE GCEXPT ATRIG-TRANS FUNCER
            XEXPONGET POLCOEF STRING1 MORP MPRINT MAXIMIN M-SUBSET ROOT
            ARRAYSIZE GETFNCOEFF P*LOGNXP PQUOTIENT PSDISREP2EXPAND
            PORM EVENFN $LOPOW TAY-EXPONENTIALIZE TRYRISCH1 MAPFR1
            OLDGCDL FREEOF RULE-APPLY AMONG RATPL EXPAND FINDPR MZFREE
            DEGODR ZFREE APPLY1HACK RTIMES INTSETUP PSDISREP^ APPLY2
            RGCD DIFF-EXPAND RIB PLCMCOFACTS PTIMES%E NARG1
            EXPAND-SING-TRIG? RESTORELC RPLUS $REMRULE RREMAINDER
            SUBST0 LOGCPI0 REMOVERULE RDIFFERENCE MREMPROP RATREP DIV
            POISCO* TYI-PARSE-INT PRNET EREDUCE EQUO SINDIF FIXVL
            MFREEL ALIKE DINTEXP SUBST-DIFF-MATCH COSDIF EXPTHACK
            DIMENSION-ARRAY-OBJECT STRONGER-VAR? POWERSET
            MCONS-EXP-ARGS DIMENSION-STRING FACTORSUM0 POISCODIF
            PSTERM1 $LISTP_CHECK NCPOWER FILLARRAY DIFFEXPT RADIC
            NCMUL2 PINTERPOLATE PSTIMES*1 RATDX1 PSCTIMES* ALLPRODS
            UNION* AP1 $FILLARRAY PINTERPOLATE1 PINTERPOLATE4
            PINTERPOLATE2 STURMSEQ RLESSP PINTERPOLATE3 RDIFFERENCE*
            ASK-INTEGER RPLUS* $FASTTIMES ASK-EVOD RREDUCE LIM-TIMES
            FPTIMES $SIMPLE_EQUAL PFACTOR2 FREE GREATERRATP PREM
            TRUNC-VECTOR FPTIMES1 STURM1 PSDISREP* HALFSPLIT
            IMPROPER-ARG-ERR TRUNC-VECT1 SUBST2S LSFT PSTRUNC1
            ASK-DECLARE IVAR DECLARRAY CHEBYF PGCDM VGREAT IVAR2 MULN
            WTPCTIMES BAKSUBST FINDROOTS ASSIGN-MODE-CHECK CEIL PNEXT
            DECLFUN NESTIFY MEMALIKE FPCOFRAT1 SOLVE3 EXCLUDE ZL-MEMBER
            $ALGSYS MGET PPLUS1 PEXPTSQ ZEROCOEFL BAKSUBST1 INTERSECT
            SOLVE1A FIRST-ORDER-P ORDERLESSP BROKEN-FREEOF
            LINEAR-TERM-P SOLVE-BY-DECOMPOSITION PTERM ASSQ ADDPARAM
            MREAD-PROMPTER CONVERT COVERS $JN Z-FUNCTION
            ATTEMPT-TRANSLATE-RANDOM-SPECIAL-OP MAXIMA-REMF
            ATTEMPT-TRANSLATE-RANDOM-MACRO-OP KCNTXT TIMEX0
            TR-LISP-FUNCTION-CALL TIMEX1 MEQP CTIMESX NEXTLEVEL COMPUMD
            $IN ASSOO $GAUSS MULTIPLYMATRICES MULTMAT MBUILDQ
            MAKE-DECLARES ADDF MBUILDQ-SUBST CNTXT APDL
            MBUILDQ-SPLICE-ASSOCIATE MBUILDQ-ASSOCIATE ASSCONTEXT
            TIMESROW SETPLIST ALPHALESSP STORE-MACRO-HELPER $DIAGMATRIX
            MULTL $CHARPOLY HAIPART POWERX FSET OLDGET DIAGINV SAFE-GET
            ZL-ASSOC PLCM $COL NTHKDR RCPLUS! NARY1 EQTEST APPEARS1
            SIMPLIFYA PSANS-ADD POWER* CONSTMX MEVALSUMARG EVENFUN
            ORDMEXPT DO%SUM PSTANA+B QUOTE-SIMPLE-EQUAL GETCHARN
            UNEQUAL-PAIRLIS PSPLUS1 G[N]-BESSEL PLS MMACRO-APPLY
            MMACROEXPANSION-CHECK PLUSIN ADDN SCMP RETRIEVE MDEFMACRO1
            GETL EXPTB MMACRO-DISPLACE RCEXPT1 MUL2 SINSP FPATAN2 ADDMX
            OUTATIVE RATEXPT HIPART SIMPMAP FPPREC1 PSCPLUS FPSINCOS1
            GETCHAR FPSHIFT PSINHA+B DIM-BIGFLOAT SPSIMPCASES
            LINEARIZE1 LASTN SEL-ERR MXPLUSC SIMPCHECK TSEXPT1
            MULTIPLICATIVE GGR FSEL GGR1 SELECTOR LASSOCIATIVE CHEBY
            SUMTIMES SPECIAL-CONVERGENT-FORMP DEFINE-MACRO CHEBY-PRIME
            DEFINE-MODE NARG-LISTIFY1 GREAT XTORTERM SUMULTIN
            MAYBE-RESET *FPSIN ADDITIVE NOTINVOLVE PSISIMP1 BIGLSH
            LESSTHAN EXPGAM-FUN COMMUTATIVE1 BYGAMMA INTERVAL
            RASSOCIATIVE DINTRAD0 INTBYTERM $SUBLIST SUMPLS ONEDIFF
            REAL-BRANCH ALIKE1 DLF-MUMBLIFY PRINT-SPACES ZGCD
            LINEARIZE2 ANTISYM ZGCD1 SQDTC FREEL EXCISE-EXTRA-VARIABLES
            SIMPARGS MSETCHK ZTOINF POLY? NO-ERR-SUB DSFUNC1 SMONO
            ASET-BY-CURSOR MTOINF ASK-GREATEQ MERGE-SKEL SMONOP
            NEW-SKEL FACTORIAL-TRANS ISINOP SUB* BXM $FUNMAKE
            EXPAND-AND-DISREP MERGE-SOL-LIN ODDFUN $ARRAYMAKE $REM
            POINTERGP SCRAT EZGCD2 RADICALP ADDROW PGCD ARRAYINFO-AUX
            SININT EXP-CONVERG-FORM PCSUBSTZ DIMENSION-ATOM DIM-MTEXT
            EVAL-MON DIMENSION-NARY LISTIFY1 GETGOODVALS ZPDEGREEVECTOR
            MAKORDER ALIAS MUL2* PCDIFCONC RTC-FIXITUP RT-SEPAR
            FIRST-FORM-LINE $GETCHAR NPCTIMES DISTRINT PMODQUO
            SIMP-ROOTS NPQUO MAXIMA-RATIONALP PPPROG RTC-DIVIDE-BY-GCD
            NPCTIMES1 ILT2 $BINOMIAL ALGTESTD RQUOTIENT CPBER3 LOGARC
            SIMPNRT *FPATAN RCEXPT CTIMEMT TMUNIFY-LOOP TMPATHP
            $COEFMATRIX $AUGCOEFMATRIX TRANSFORM-TVAR TMDET
            ITERATE-OVER-BKPTS RATCOEF CONST1 $ENTERMATRIX TSEXPT
            TMERGE NISSWCAR NISTREELISTER BEG TMCOMBI NISTREETRIMMER
            EMAX REMOV4 NISSWCDR ZL-REMPROP $BOTHCOEF NISREPLACE MARK+
            MSET NISFIX TAY-ERROR LISTN PSDERIVATIVE HALFANGLE
            HALFANGLEAUX MERGEF GET! CALL-BATCH1 REM-TRACE-INFO TAYLOR*
            TRACE-UNFSHADOW TAYLOR1 TRACE-OPTION-P
            MICRO-PER-CALL-TO-SEC TRACE-HANDLER PRINT-ABORT-MSG
            SP1TPLUS SP1TLIN SP1SINCOS SUBRESGCD REDGCD TIMER-HANDLER
            SP1SINTCOS ALGTRACE POLY-IN-VAR SP1SINCOS2 MONOMGCD RADFUNP
            PGCD2 ALGNORM OLDCONTENT1 $SPLITFIELD CONTODR PCONTENT1
            CGCD CONSTERM RATSETUP PCQUOTIENT1 PNTHROOT INTIR CNTHROOT
            INTE PSINA+B NMT ORDFN CREMAINDER ORDFNA INTIR-REF IROOT
            CQUOTIENT NRTHK INTIR3 PFACTORLIN RADSUBST EGCD PSIMP
            INVMOD NRTHK1 INTIR2 RE-ERAT PDIVIDE NRTHK2 PCPLUS FFACTOR
            INTIR1 PSCOSA+B LIMITSIMP-EXPT $INRT PCDIFFER PLSK RATCOEF1
            RETFACTOR1 RATP $AT PDERIVATIVE3 FACTOROUT1 ELLIPTQUAD
            EXPTA $POLYDECOMP REMOVE-SINGULARITIES FREEOFL PDECOMP1
            PCTIMES1 TIMESKL INTIRFACTOROOT PSDISREP*EXPAND CBEXPT
            $-READ-AUX $PARTFRAC FACTPOW RATDIFFERENCE PCPLUS1 PSCPLUS1
            RATINT PCDIFFER2 HEURTRIAL INTIRA FREEARGS CFTIMES RCDIFF!
            PCDIFFER1 FIXMULT JMAUG TMKILL APPEARS PDIVIDE1 $ORDERLESSP
            EXTRACT PSIMP2 $ORDERGREATP CONF5 SUBSTITUTE-KEYWORD-ARG
            RATFACT DISTRFACTOR MULT XPTIMES CFEXPT SP2DIFF TMSYMETRICP
            FACTOROOT HAND-SIDE CAREFULFACTOR SP2SUB PTIMES*
            TMSORT-LATTICE RESTOREX EXT-1M EVERYSUBST2 SRATP PAIROFF
            CONF4 RATDP1 ROOT+ANYTHING CONF7 DISTRESTOREX RESTOROOT
            CONF6 COMPATIBLE-ARRAY-TYPE? OLDGCD WRAP-AN-IS *DIF
            MAKE-GTRAMP SRATEXPND PUSH-AUTOLOAD-DEF RATEXAND1 TRAMP2$-M
            ADFACTL TRAMP2$-F TR-MAREF NXTBINCOEF TR-ARRAYSETQ DPGCD
            DUP MAKE-GTRAMP$ DPDIF REDUCE-VAR-SET&OP ZERORES DPMODQUO
            DPMODREM CFPLUS XOR DIFFERENCE-VAR-SETS $ZEROEQUIV *RED
            C-$PN EXPANDTERMS EXPANDSUMS C-$POS ATAN INFSIMP1 MNQP
            INFSIMP2 CFDIFF INTEXT YUK-SU-META-PROP SUM MLSP C-$ZERO
            C-$PZ $GN MGQP DCOMP DEQ $BESSEL OBSOLETE-VARIABLE TIMEX
            NEWVARMAT SIGNDIFF-SPECIAL KINDP SINH^N SAFE-MGET DCOMPARE
            NUMERSET COS^N COSH^N  NEVERSET DGQ MAXIMA-REDUCE
            RGRP EVFUNMAKE DLQ MCONS MEVAL2 $COMPARE MSETERR MMOD
            %PIARGS MFORMAT-TRANSLATE MTELL-TRANSLATE TRIGEXPAND REMOV0
            MULTIPLEP SQ-SUMSQ REMOV3 MERROR-TRANSLATE ERRRJF-TRANSLATE
            RATQU PQUO PTIMES1 CEXPT FPGCDCO DISPLAF PQUOCOF ORDE
            QUICK-SQFR-CHECK |''MAKE-FUN| LMAKE LMAKE2 $ISOLATE
            CREATE-LIST2 PGCDCOFACTS MARK- LGCD1 NEWSYM2 $PICKAPART
            $REVEAL MAKPRODG MAKPROD OFFP ONP DOPGCDCOFACTS UNION1
            FACRPLUS ONPU PTIMESCHK ZFACTSPLIT UPOLY+ FSPLIT
            OLDCONTENT2 BEG- TERM* ESHIFT PADE1 KLIM LET-MACRO-GET-VARS
            PADE-MONIZE NALGFAC END- END MID- ASY CANCEL MEMQ MID RDDEG
            LHOP-NUMDEN ASSOL TRIG-RIGHT-PLACEP LIMITSIMP XXORM
            LIMITSIMP-DISPATCH POISLIM1 POISXCOEF $POISINT INSERT-IT
            LPR LABEQ POISCO+ PAR IND1 PATAN RATQUOTIENT ORMAPC BDISCR
            RATDIF ITH BINCOMP1 EXCHANGEVAR PSQFRP BINOCOMP ORDERVAR
            RESULTANT PSCSUBST1 ALGTRACE1 PSEXPT ALGTRACE* EMIN BINCOMP
            $ZEROMATRIX PSDIFF TMSTORE LED-CALL NTHCOL1 DELETECOL
            DELETEROW $ROW MXTIMESC TRIG-SUBST STIMEX MAYBPC ADDMATRIX
            PSTRIM-TERMS ADDMATRIX1 LINPOWER0 ADDROWS PSTERM ERFARG2
            LINPOWER ERFARG PSTIMES FIND1 EASY-CASES MATCHSUM PARTNUM
            INTGREAT E> LSAFIX E* TRIGINT RESTORE-DEFINT-ASSUMPTIONS
            FPR-DIF $HIPOW FINDFLIST FINDPOWERS SUBLISS USOLVE
            SPDERIVATIVE $BERNPOLY TIMESLOOP POWER RISCHEXPPOLY ADDK
            SCEP ODDFN LINEARP DIV* SHEUR FACTQSNT RISCHINT FSGEO RHEUR
            FBINO CPROG OPERATOR-FREQUENCY-TABLE INTSUM CFQUOT CNV
            RE-SOLVE-FULL HIDELIM FACTPLUS2 EXPANDS SHEUR0
            BATCH-INTERNAL FACTPLUSDEP INTEGRATE5 SSOLVE INTEGRATOR
            WLINEARPOLY $RISCH BEHAVIOR-EXPT LOGEQUIV *QUO DIFFDIV
            PMON1 CHOICESIN VARINVERT MAKE-LI PQUOTIENT1 PUTLIMVAL
            PQUOTIENT2 ATRANSPOSE PDECPOW POWERLIST $LINSOLVE MXCOMP
            RATREDUCE CAR> EXPFACTORP ROMBERG-MACRO MAKE-TRAMP$
            MAKE-INPUT-STREAM PDERIVATIVE TAYLIM LODEG GPDIFFERENCE
            PATIMES DOT-SP-RI BRANCH1 RAT3 PQUOTIENTCHK POWERS TIMESK
            CONST GCPOWER NZEROS PCQUOTIENT AMONGL INTERPOLATE-MACRO
            GENATAN PDECOMP MEMBERCAR SOLVESPEC ISGREATERP LOCOEF
            SIGNNP PDIFFER1 GPTIMES LINSORT EXPAND-TRIGS PREVCONSTEXPAN
            DOT--RI DISTRINTIMESPREV EXCHANGECOL SPC3 GPPLUS PAQUO
            MCONS-OP-ARGS DISTRINPLUSPREV GPCTIMES POLYDECOMP DGR
            INSIDE MDEFINE1 PSIMP1 CPA1 RAT EXCHANGEROW DETPIVOT
            DIVCARCDR STRONGP $SUBLIS DECLAREKIND MSUBLIS MKIND
            MSUBLIS-SUBST REMARRELEM LIKE REMVALUE LEARN GATHER
            |/#ALIKE| SUMCONTRACT2 DADDNQ SUMCOMBINE1 DADDEQ REMALIAS1
            SUMCOMBINE2 DADDGQ DADDGR SIMPLIMSUBST ZL-GET DECLSETUP
            PAGEPAUSE1 GETL-LM-FCN-PROP MFUNCTION-DELETE GCTIMEP DLS
            SP1GREAT DEBUGMODE1 KIND BOTHCASES1 GETLABELS* SUB DNQ
            DMARK SP1ATRIG SP1ATRIG2 SAFE-MGETL SIN^N CYCLP
            MFUNCTION-CALL-WARN $POISDIFF MGRIND EXPT$ MAKE-M-LAMBDA&
            TSTIMES-GET-PW STRONGER-DATUM? EXPONENTIALIZE EXPTBIGFLOAT
            FPGREATERP FPLESSP FPEXPT FPTIMES* |$SSTATUS-aux|
            FPQUOTIENT FPROOT FPDIFFERENCE EXPANINTEXPT FPSIN EXPTRL
            FPPLUS DSKGC1 MAXMINL REPRINT BYLOG HEURTRIAL1
            SIDE-EFFECT-FREE-CHECK NOT-ZERO-FREE $NTHROOT LINEAR*
            $FEATUREP M1 $GET ALGPCHK START-VAL DIM-MBOX
            SIMPLIM%ERF-%TANH SIMPLIMSCH DIMENSION-FUNCTION EACHP
            DIMENSION-ARRAY LOOPP DIMENSION-PAREN PDISREP2 BRANCH
            PDISREP2EXPAND DIM-MLABOX EPS-COEF-SIGN RATSETUP2 SCHATCHEN
            ALGORDSET TRDISP1 QUEUE+P SIMPLIM%ASIN-%ACOS FINDTHEM
            SCH-LOOP FDEL SCH-REPLACE QUEUE-P RATSETUP1 TOTAL-SIGN
            PDISREP* UNKIND PDISREP! PDISREP*EXPAND SCS FANCYDIS
            $FACOUT DIM-MLABEL LIMFACT SPANGSIDE ADD2CSTR1 SP3FORM
            DIM-MDEFINE DIMENSION-INFIX PRENUMBER)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL FIXNUM) [MAX-TRUNC] CHRCT* REALIT-SL STERPRI
            LISTEN CHRCT SYS-GCTIME)) 
(PROCLAIM
    '(FTYPE (FUNCTION NIL (VALUES T T)) SCAN-MACSYMA-STRING
            SCAN-LISP-STRING SCAN-KEYWORD-TOKEN))


(proclaim
 '(ftype (function * t) meval1
	 quot merror errrjf sort typep inf-signal mread $filename_merge
	 maclisp-typep SCAN-DIGITS dimension maset1 error cerror
	 $file_search mtell))


(proclaim '(SPECIAL
	    	    *mlambda-call-stack* *LAST-MEVAL1-FORM*
  TRIM TRIM *EU* *BD* *BN* $MAXPRIME $ASSUMESCALAR $DOTIDENT
  $SCALARMATRIXP $DOMXNCTIMES $DOSCMXOPS $DOMXMXOPS $DOALLMXOPS
  $DOTASSOC $DOTEXPTSIMP $DOTDISTRIB $DOTSCRULES $DOT1SIMP
  $DOT0NSCSIMP $DOT0SIMP $DOTCONSTRULES $OPTIMWARN $OPTIMPREFIX
  *SUBEXP* $FORTFLOAT $FORTINDENT $FORTSPACES $OPPROPERTIES OPERS
  *OPERS-LIST *INFSUMSIMP $PRODHACK $SUMHACK $SIMPSUM $ZEROBERN
  $GENINDEX $GENSUMNUM $CAUCHYSUM $ZETA%PI $TIMER_DEVALUE
  GCTIME-DEVALUE RUNTIME-DEVALUE $TIMER $TRACE_MAX_INDENT
  $TRACE_BREAK_ARG $TRACE_SAFETY RETURN-TO-TRACE-HANDLE
  PREDICATE-ARGLIST TRACE-INDENT-LEVEL TRACE-HANDLING-STACK
  HARD-TO-TRACE $TRACE ALGNOTEXACT $ALGEXACT REALONLYRATNUM $REALONLY
  $%RNUM_LIST $ALGDELTA FLAG4 $SOLVERADCAN $SOLVETRIGWARN
  $SOLVENULLWARN $SOLVEFACTORS $SOLVEEXPLICIT $SOLVEDECOMPOSES
  $PROGRAMMODE $SOLVE_INCONSISTENT_ERROR $LINSOLVEWARN $MULTIPLICITIES
  $BREAKUP PRESERVE-DIRECTION LIMIT-ANSWERS SIMPLIMPLUS-PROBLEMS RD*
  INFINITESIMALS REAL-INFINITIES INFINITIES $LET_RULE_PACKAGES
  $CURRENT_LET_RULE_PACKAGE $DEFAULT_LET_RULE_PACKAGE $LETRAT
  $LETVARSIMP MATCHREVERSE $MAXAPPLYHEIGHT $MAXAPPLYDEPTH *TMARRAYS*
  $MATRIX_ELEMENT_TRANSPOSE $MATRIX_ELEMENT_ADD $MATRIX_ELEMENT_MULT
  $RATMX TOP* $DETOUT $LINSOLVE_PARAMS $%RNUM *MOSESFLAG SOLVEXP *INV*
  *RANK* $BACKSUBST $SPARSE $GLOBALSOLVE *S12* *LI3* *LI2* PIBY2
  -SQRT3//2 SQRT3//2 -SQRT2//2 SQRT2//2 %PI//2 %PI//4 |-1//2| |1//2|
  $HALFANGLES $LOGARC $EXPONENTIALIZE $TRIGSIGN $TRIGEXPANDTIMES
  $TRIGEXPANDPLUS $TRIGEXPAND $TRIGINVERSES $%IARGS $%PIARGS
  NONINTEGERL INTEGERL DEFINTDEBUG TRUNC-CONSTANTS?
  $TAYLOR_ORDER_COEFFICIENTS TVAR-LIMITS $TAYLOR_SIMPLIFIER
  $TAYLOR_LOGEXPAND $TAYLOR_TRUNCATE_POLYNOMIALS $MAXTAYORDER
  $PSEXPAND *WITHIN-SRF?* TLIST CHANGEVP $ERFFLAG $LIFLAG
  $INTEGRATION_CONSTANT_COUNTER COMPLEXSIGN RHS LHS EVENS ODDS MINUS
  SIGN PATEVALLED LOCALS FACTORED $ASSUME_POS_PRED $ASSUME_POS LIMITP
  $ASKEXP $SIGNBFLOAT $PREDERROR COMPLEXSIGN SIGN-IMAG-ERRP
  $ACTIVECONTEXTS $CONTEXTS $CONTEXT CONMARK CONUNMRK LAB-HIGH-LAB
  LABNUMBER LAB-HIGH-BIT CONNUMBER CONINDEX ULABS -L +L MARKS NOBJECTS
  DOBJECTS DBCHECK DBTRACE -LABS +LABS CURRENT CONTEXTS CONTEXT
  $POLYFACTOR $LISTDUMMYVARS $LISTCONSTVARS *DESCRIBE-INDEX-DIRECTORY*
  *INDEX-FILE-TYPE* *DESCRIBE-INDICES* $ALL_MACSYMA_DOCUMENTATION
  $DESCRIBE_DOCUMENTATION *PDP-DESCRIBE* *WORD* $POINTBOUND *ALPHA RB
  LB FORTRANP $NEGSUMDISPFLAG $SQRTDISPFLAG $EXPTDISPFLAG $%EDISPFLAG
  $PFEFORMAT $POWERDISP ATOM-CONTEXT $DISPLAY_FORMAT_INTERNAL
  LINEARRAY $RMXCHAR $LMXCHAR $ABSBOXCHAR $BOXCHAR D-MOREFLUSH
  D-MOREMSG DISPLAYP STRINGDISP $NOUNDISP $DERIVABBREV $LINEDISP
  $LISPDISP $DISPLAY2D $LEFTJUST $STARDISP $CURSORDISP
  LINE-GRAPHICS-TTY CHARACTER-GRAPHICS-TTY $PARSEWINDOW
  SCAN-BUFFERED-TOKEN *SCAN-STRING-BUFFER* PARSE-TYI PARSE-TYIPEEK
  *MREAD-EOF-OBJ* *MREAD-PROMPT* MACSYMA-OPERATORS *PARSE-STREAM*
  ALPHABET ALPHABET ROMB-PRINT $ROMBERGIT_USED $ROMBERGABS $ROMBERGTOL
  $ROMBERGMIN $ROMBERGIT TRAMP$-ALIST 
  *UNKNOWN-FUNCTIONS-INFO-STACK* *KNOWN-FUNCTIONS-INFO-STACK*
  META-PROP-L META-PROP-P *FCALL-MEMORY* *TR-RUNTIME-WARNED*
  $TR_WARN_BAD_FUNCTION_CALLS FORMS-TO-COMPILE-QUEUE
  A-RANDOM-COUNTER-FOR-GEN-NAME *INFILE-NAME-KEY* *MAX-EXPT$-EXPAND*
  *NUMBER-TYPES* WRAP-AN-IS $MACSYMA_EXTEND_WARNP $MODE_CHECK_ERRORP
  $MODE_CHECK_WARNP $MODE_CHECKP $TR_EXPONENT
  $TR_FLOAT_CAN_BRANCH_COMPLEX VALUE-ALIST UNBOUND-MEVAL-KLUDGE-FIX
  LISP->LISP-TR-LAMBDA $TRANSLATE_FAST_ARRAYS TRF-START-HOOK
  *PRETTY-PRINT-TRANSLATION* $TR_GEN_TAGS TR-DEFAULTF $TR_STATE_VARS
  $TR_TRUE_NAME_OF_FILE_BEING_TRANSLATED $COMPGRIND TRANSL-FILE
  $TR_WINDY $TR_FILE_TTY_MESSAGESP $TR_OUTPUT_FILE_DEFAULT
  *TRANSL-FILE-DEBUG* $TR_BIND_MODE_HOOK $TR_BOUND_FUNCTION_APPLYP
  $TR_OPTIMIZE_MAX_LOOP *$ANY-MODES* WARNED-UNDEFINED-VARIABLES
  *TR-WARN-BREAK* TR-LAMBDA-PUNT-ASSIGNS MODE-INIT-VALUE-TABLE
  BOOLEAN-OBJECT-TABLE $TR_PREDICATE_BRAIN_DAMAGE $TR_NUMER
  $TR_ARRAY_AS_REF $TR_FUNCTION_CALL_DEFAULT *WARNED-MODE-VARS*
  *WARNED-FEXPRS* *WARNED-UN-DECLARED-VARS*
  $TR_WARN_UNDEFINED_VARIABLE $TR_WARN_MODE $TR_WARN_FEXPR
  $TR_WARN_MEVAL $TR_WARN_UNDECLARED TR-UNIQUE TR-ABORT *TRANSL-DEBUG*
  *TRANSL-BACKTRACE* TRANSLATE-TIME-EVALABLES SPECIALS ASSIGNS
  NEED-PROG? RETURN-MODE RETURNS INSIDE-MPROG TR-PROGRET FEXPRS EXPRS
  LEXPRS ARRAYS LOCAL TSTACK $SPECIAL $TRANSCOMPILE $TR_SEMICOMPILE
  *UNTRANSLATED-FUNCTIONS-CALLED* $TRANSBIND MODULE-STACK
  TRANSL-MODULES ARGSFREEOFP $RADSUBSTFLAG $RATDENOMDIVIDE $RATEXPAND
  $RATEPSILON $RATPRINT FR-FACTOR *WITHINRATF* ALPHA ADN* INRATSIMP
  TELLRATLIST $FACEXPAND $RATVARS $ALGEBRAIC $RATFAC $RATWEIGHTS
  $NOREPEAT $DONTFACTOR $FACTORFLAG $KEEPFLOAT FACTORRESIMP *RATSIMP*
  *RATWEIGHTS *FNEWVARSW VARLIST GENPAIRS GENVAR *ALPHA BIGPRIMES $GCD
  *GCDL* $HOMOG_HACK CHECKFACTORS $SAVEFACTORS $BERLEFACT $INTFACLIM
  LOW* ALGFAC* *IRREDS $RATALGDENOM $RATWTLVL ERRRJFFLAG HMODULUS
  MODULUS *RESULTLIST $RESULTANT THR* $NEWFAC $NALGFAC SMALLPRIMES
  ALPHA MM* MPLC* MINPOLY* *MX* *MIN* GAUSS
  *MACSYMA-EXTEND-TYPES-SAVED*
  $DONT_KILL_SYMBOLS_WITH_LISP_SOURCE_FILES AUTOLOAD $SHOWTIME
  $FILE_STRING_PRINT $CHANGE_FILEDEFAULTS ALIASLIST $SHOWTIME
  $MOREWAIT MOREFLUSH MORECONTINUE MOREMSG USER-TIMESOFAR CASEP $DIREC
  $LINENUM $LINECHAR $OUTCHAR $INCHAR $% $PROMPT MOPL *COLLECT-ERRORS*
  
  $FILE_TYPES *MACSYMA-STARTUP-QUEUE*  $CANONICAL_TYPES
  ACCUMULATED-TIME $__ $_ ABSFLAG GENERATE-ATAN2 IMPLICIT-REAL
  $BETA_ARGS_SUM_TO_INTEGER $GAMMALIM $SUMSPLITFACT HALF%PI3 %PI2
  HALF%PI FOURTH%PI %P%I MAX-BFLOAT-%E MAX-BFLOAT-%PI *DECFP *M FPPREC
  BIGFLOAT%PI BIGFLOAT%E BFMHALF BFHALF BIGFLOATONE BIGFLOATZERO
  $FPPREC $FPPRINTPREC $BFTRUNC $BFTORAT $FLOAT2BF *AFTERFLAG
  DERIVSIMP ERRORSW DOSIMP $MAXNEGEX
  $MAXPOSEX $EXPON $EXPOP $MX0SIMP $DOMXTIMES $DOMXPLUS $DOMXEXPT
  $DOSCMXPLUS $NUMER_PBRANCH $SUMEXPAND $SIMP $NUMER $NEGDISTRIB
  $FLOAT $MACROEXPANSION $USE_FAST_ARRAYS $SETCHECK MUNBINDP
  FLOUNBOUND FIXUNBOUND MUNBOUND $ROOTSCONMODE $SUPERLOGCON
  SUPERLOGCON $LOGCONCOEFFP DUMMY-VARIABLE-OPERATORS $VECT_CROSS
  $COMBINEFLAG $ISOLATE_WRT_TIMES $EXPTISOLATE $ERROR_SYMS $ERROR_SIZE
  $ERRORMSG $ERROR DEBUG $SUBLIS_APPLY_LAMBDA $NICEINDICESPREF
  $RATVARSWITCH CANT-OPEN-COMPILE-MFORMAT WANT-OPEN-COMPILED-MFORMAT
  MBINDING-USAGE TTYOFF WRITEFILEP MACSYMA-OPERATORS SYMBOLS-DEFINED
  USE-SUBRCALL *ALL-ARRAYS* ^R ^W FORWARD-SLASH-STRING
  $FORWARD-SLASH-SYMBOL VERTICAL-STROKE-CHAR PERIOD-CHAR
  RIGHT-PARENTHESES-CHAR LEFT-PARENTHESES-CHAR FORWARD-SLASH-CHAR
  BACK-SLASH-CHAR SEMI-COLON-CHAR DOUBLE-QUOTE-CHAR *RESET-VAR*
  *MACSYMA-READTABLE* *SHARP-READ-BUFFER* *SCAN-STRING-BUFFER*
  *MAXIMA-ARRAYS* *CL-MAKE-ARRAY-OPTION-REPLACEMENTS*
  *MAKE-ARRAY-OPTION-REPLACEMENTS* *PRIMITIVE-DATA-TYPE-FUNCTION*
  *ALLOW-REDEFINES* PRIN1 ERRSET *SHOW-ALL-DEBUG-INFO*
  *CATCH-ERROR-STACK* *DISABLE-CATCH-ERROR* *CATCH-ERROR*
  *ERROR-HANDLER-FUNCTION* *MACRO-FILE*))
